<?php

use Elementor\Controls_Manager;
use Elementor\Widget_Base;

class Osteo_Syntax_Highlighter extends \Elementor\Widget_Base {

    public function get_name() {
        return "Osteo_Syntax_Highlighter";
    }

    public function get_title() {
        return esc_html__( "Osteo Syntax Highlighter", 'osteo-accordion' );
    }

    public function get_icon() {
        return 'eicon-code';
    }

    public function get_keywords() {
        return ['Syntax Highlighter', 'Syntax', 'Highlighter', 'Code'];
    }

    public function get_categories() {
        return array( 'basic' );
    }

    protected function register_controls() {

        $this->start_controls_section(
            'osteo_syntax_highlighter_content_section',
            [
                'label' => esc_html__( 'Content', 'osteo-syntax-highlighter' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_language',
            [
                'label'   => esc_html__( 'Select Language', 'osteo-syntax-highlighter' ),
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'default' => 'language-php',
                'options' => [
                    'language-markup'                   => esc_html__( 'Markup', 'osteo-syntax-highlighter' ),
                    'language-css'                      => esc_html__( 'CSS', 'osteo-syntax-highlighter' ),
                    'language-clike'                    => esc_html__( 'C-like', 'osteo-syntax-highlighter' ),
                    'language-javascript'               => esc_html__( 'JavaScript', 'osteo-syntax-highlighter' ),
                    'language-abap'                     => esc_html__( 'ABAP', 'osteo-syntax-highlighter' ),
                    'language-abnf'                     => esc_html__( 'ABNF', 'osteo-syntax-highlighter' ),
                    'language-actionscript'             => esc_html__( 'ActionScript', 'osteo-syntax-highlighter' ),
                    'language-ada'                      => esc_html__( 'Ada', 'osteo-syntax-highlighter' ),
                    'language-agda'                     => esc_html__( 'Agda', 'osteo-syntax-highlighter' ),
                    'language-al'                       => esc_html__( 'AL', 'osteo-syntax-highlighter' ),
                    'language-antlr4'                   => esc_html__( 'ANTLR4', 'osteo-syntax-highlighter' ),
                    'language-apacheconf'               => esc_html__( 'Apache Configuration', 'osteo-syntax-highlighter' ),
                    'language-apex'                     => esc_html__( 'Apex', 'osteo-syntax-highlighter' ),
                    'language-apl'                      => esc_html__( 'APL', 'osteo-syntax-highlighter' ),
                    'language-applescript'              => esc_html__( 'AppleScript', 'osteo-syntax-highlighter' ),
                    'language-aql'                      => esc_html__( 'AQL', 'osteo-syntax-highlighter' ),
                    'language-arduino'                  => esc_html__( 'Arduino', 'osteo-syntax-highlighter' ),
                    'language-asciidoc'                 => esc_html__( 'AsciiDoc', 'osteo-syntax-highlighter' ),
                    'language-aspnet'                   => esc_html__( 'ASP.NET (C#)', 'osteo-syntax-highlighter' ),
                    'language-arff'                     => esc_html__( 'ARFF', 'osteo-syntax-highlighter' ),
                    'language-asm6502'                  => esc_html__( '6502 Assembly', 'osteo-syntax-highlighter' ),
                    'language-asmatmel'                 => esc_html__( 'Atmel AVR Assembly', 'osteo-syntax-highlighter' ),
                    'language-autohotkey'               => esc_html__( 'AutoHotkey', 'osteo-syntax-highlighter' ),
                    'language-autoit'                   => esc_html__( 'AutoIt', 'osteo-syntax-highlighter' ),
                    'language-avisynth'                 => esc_html__( 'AviSynth', 'osteo-syntax-highlighter' ),
                    'language-avro-idl'                 => esc_html__( 'Avro IDL', 'osteo-syntax-highlighter' ),
                    'language-bash'                     => esc_html__( 'Bash', 'osteo-syntax-highlighter' ),
                    'language-basic'                    => esc_html__( 'BASIC', 'osteo-syntax-highlighter' ),
                    'language-batch'                    => esc_html__( 'Batch', 'osteo-syntax-highlighter' ),
                    'language-bbcode'                   => esc_html__( 'BBcode', 'osteo-syntax-highlighter' ),
                    'language-bicep'                    => esc_html__( 'Bicep', 'osteo-syntax-highlighter' ),
                    'language-birb'                     => esc_html__( 'Birb', 'osteo-syntax-highlighter' ),
                    'language-bison'                    => esc_html__( 'Bison', 'osteo-syntax-highlighter' ),
                    'language-bnf'                      => esc_html__( 'BNF', 'osteo-syntax-highlighter' ),
                    'language-brainfuck'                => esc_html__( 'Brainfuck', 'osteo-syntax-highlighter' ),
                    'language-brightscript'             => esc_html__( 'BrightScript', 'osteo-syntax-highlighter' ),
                    'language-bro'                      => esc_html__( 'Bro', 'osteo-syntax-highlighter' ),
                    'language-bsl'                      => esc_html__( 'BSL', 'osteo-syntax-highlighter' ),
                    'language-c'                        => esc_html__( 'C', 'osteo-syntax-highlighter' ),
                    'language-csharp'                   => esc_html__( 'C#', 'osteo-syntax-highlighter' ),
                    'language-cpp'                      => esc_html__( 'C++', 'osteo-syntax-highlighter' ),
                    'language-cfscript'                 => esc_html__( 'CFScript', 'osteo-syntax-highlighter' ),
                    'language-chaiscript'               => esc_html__( 'ChaiScript', 'osteo-syntax-highlighter' ),
                    'language-cil'                      => esc_html__( 'CIL', 'osteo-syntax-highlighter' ),
                    'language-clojure'                  => esc_html__( 'Clojure', 'osteo-syntax-highlighter' ),
                    'language-cmake'                    => esc_html__( 'CMake', 'osteo-syntax-highlighter' ),
                    'language-cobol'                    => esc_html__( 'COBOL', 'osteo-syntax-highlighter' ),
                    'language-coffeescript'             => esc_html__( 'CoffeeScript', 'osteo-syntax-highlighter' ),
                    'language-concurnas'                => esc_html__( 'Concurnas', 'osteo-syntax-highlighter' ),
                    'language-csp'                      => esc_html__( 'Content Security Policy', 'osteo-syntax-highlighter' ),
                    'language-coq'                      => esc_html__( 'Coq', 'osteo-syntax-highlighter' ),
                    'language-crystal'                  => esc_html__( 'Crystal', 'osteo-syntax-highlighter' ),
                    'language-css-extras'               => esc_html__( 'CSS Extras', 'osteo-syntax-highlighter' ),
                    'language-csv'                      => esc_html__( 'CSV', 'osteo-syntax-highlighter' ),
                    'language-cypher'                   => esc_html__( 'Cypher', 'osteo-syntax-highlighter' ),
                    'language-d'                        => esc_html__( 'D', 'osteo-syntax-highlighter' ),
                    'language-dart'                     => esc_html__( 'Dart', 'osteo-syntax-highlighter' ),
                    'language-dataweave'                => esc_html__( 'DataWeave', 'osteo-syntax-highlighter' ),
                    'language-dax'                      => esc_html__( 'DAX', 'osteo-syntax-highlighter' ),
                    'language-dhall'                    => esc_html__( 'Dhall', 'osteo-syntax-highlighter' ),
                    'language-diff'                     => esc_html__( 'Diff', 'osteo-syntax-highlighter' ),
                    'language-django'                   => esc_html__( 'Django/Jinja2', 'osteo-syntax-highlighter' ),
                    'language-dns-zone-file'            => esc_html__( 'DNS zone file', 'osteo-syntax-highlighter' ),
                    'language-docker'                   => esc_html__( 'Docker', 'osteo-syntax-highlighter' ),
                    'language-dot'                      => esc_html__( 'DOT (Graphviz)', 'osteo-syntax-highlighter' ),
                    'language-ebnf'                     => esc_html__( 'EBNF', 'osteo-syntax-highlighter' ),
                    'language-editorconfig'             => esc_html__( 'EditorConfig', 'osteo-syntax-highlighter' ),
                    'language-eiffel'                   => esc_html__( 'Eiffel', 'osteo-syntax-highlighter' ),
                    'language-ejs'                      => esc_html__( 'EJS', 'osteo-syntax-highlighter' ),
                    'language-elixir'                   => esc_html__( 'Elixir', 'osteo-syntax-highlighter' ),
                    'language-elm'                      => esc_html__( 'Elm', 'osteo-syntax-highlighter' ),
                    'language-etlua'                    => esc_html__( 'Embedded Lua templating', 'osteo-syntax-highlighter' ),
                    'language-erb'                      => esc_html__( 'ERB', 'osteo-syntax-highlighter' ),
                    'language-erlang'                   => esc_html__( 'Erlang', 'osteo-syntax-highlighter' ),
                    'language-fsharp'                   => esc_html__( 'F#', 'osteo-syntax-highlighter' ),
                    'language-factor'                   => esc_html__( 'Factor', 'osteo-syntax-highlighter' ),
                    'language-false'                    => esc_html__( 'False', 'osteo-syntax-highlighter' ),
                    'language-firestore-security-rules' => esc_html__( 'Firestore security rules', 'osteo-syntax-highlighter' ),
                    'language-flow'                     => esc_html__( 'Flow', 'osteo-syntax-highlighter' ),
                    'language-fortran'                  => esc_html__( 'Fortran', 'osteo-syntax-highlighter' ),
                    'language-ftl'                      => esc_html__( 'FreeMarker Template Language', 'osteo-syntax-highlighter' ),
                    'language-gml'                      => esc_html__( 'GameMaker Language', 'osteo-syntax-highlighter' ),
                    'language-gap'                      => esc_html__( 'GAP', 'osteo-syntax-highlighter' ),
                    'language-gcode'                    => esc_html__( 'G-code', 'osteo-syntax-highlighter' ),
                    'language-gdscript'                 => esc_html__( 'GDScript', 'osteo-syntax-highlighter' ),
                    'language-gedcom'                   => esc_html__( 'GEDCOM', 'osteo-syntax-highlighter' ),
                    'language-gherkin'                  => esc_html__( 'Gherkin', 'osteo-syntax-highlighter' ),
                    'language-git'                      => esc_html__( 'Git', 'osteo-syntax-highlighter' ),
                    'language-glsl'                     => esc_html__( 'GLSL', 'osteo-syntax-highlighter' ),
                    'language-gn'                       => esc_html__( 'GN', 'osteo-syntax-highlighter' ),
                    'language-go'                       => esc_html__( 'Go', 'osteo-syntax-highlighter' ),
                    'language-go-module'                => esc_html__( 'Go module', 'osteo-syntax-highlighter' ),
                    'language-graphql'                  => esc_html__( 'GraphQL', 'osteo-syntax-highlighter' ),
                    'language-groovy'                   => esc_html__( 'Groovy', 'osteo-syntax-highlighter' ),
                    'language-haml'                     => esc_html__( 'Haml', 'osteo-syntax-highlighter' ),
                    'language-handlebars'               => esc_html__( 'Handlebars', 'osteo-syntax-highlighter' ),
                    'language-haskell'                  => esc_html__( 'Haskell', 'osteo-syntax-highlighter' ),
                    'language-haxe'                     => esc_html__( 'Haxe', 'osteo-syntax-highlighter' ),
                    'language-hcl'                      => esc_html__( 'HCL', 'osteo-syntax-highlighter' ),
                    'language-hlsl'                     => esc_html__( 'HLSL', 'osteo-syntax-highlighter' ),
                    'language-hoon'                     => esc_html__( 'Hoon', 'osteo-syntax-highlighter' ),
                    'language-http'                     => esc_html__( 'HTTP', 'osteo-syntax-highlighter' ),
                    'language-hpkp'                     => esc_html__( 'HTTP Public-Key-Pins', 'osteo-syntax-highlighter' ),
                    'language-hsts'                     => esc_html__( 'HTTP Strict-Transport-Security', 'osteo-syntax-highlighter' ),
                    'language-ichigojam'                => esc_html__( 'IchigoJam', 'osteo-syntax-highlighter' ),
                    'language-icon'                     => esc_html__( 'Icon', 'osteo-syntax-highlighter' ),
                    'language-icu-message-format'       => esc_html__( 'ICU Message Format', 'osteo-syntax-highlighter' ),
                    'language-idris'                    => esc_html__( 'Idris', 'osteo-syntax-highlighter' ),
                    'language-ignore'                   => esc_html__( 'ignore', 'osteo-syntax-highlighter' ),
                    'language-inform7'                  => esc_html__( 'Inform 7', 'osteo-syntax-highlighter' ),
                    'language-ini'                      => esc_html__( 'Ini', 'osteo-syntax-highlighter' ),
                    'language-io'                       => esc_html__( 'Io', 'osteo-syntax-highlighter' ),
                    'language-j'                        => esc_html__( 'J', 'osteo-syntax-highlighter' ),
                    'language-java'                     => esc_html__( 'Java', 'osteo-syntax-highlighter' ),
                    'language-javadoc'                  => esc_html__( 'JavaDoc', 'osteo-syntax-highlighter' ),
                    'language-javadoclike'              => esc_html__( 'JavaDoc-like', 'osteo-syntax-highlighter' ),
                    'language-javastacktrace'           => esc_html__( 'Java stack trace', 'osteo-syntax-highlighter' ),
                    'language-jexl'                     => esc_html__( 'Jexl', 'osteo-syntax-highlighter' ),
                    'language-jolie'                    => esc_html__( 'Jolie', 'osteo-syntax-highlighter' ),
                    'language-jq'                       => esc_html__( 'JQ', 'osteo-syntax-highlighter' ),
                    'language-jsdoc'                    => esc_html__( 'JSDoc', 'osteo-syntax-highlighter' ),
                    'language-js-extras'                => esc_html__( 'JS Extras', 'osteo-syntax-highlighter' ),
                    'language-json'                     => esc_html__( 'JSON', 'osteo-syntax-highlighter' ),
                    'language-json5'                    => esc_html__( 'JSON5', 'osteo-syntax-highlighter' ),
                    'language-jsonp'                    => esc_html__( 'JSONP', 'osteo-syntax-highlighter' ),
                    'language-jsstacktrace'             => esc_html__( 'JS stack trace', 'osteo-syntax-highlighter' ),
                    'language-js-templates'             => esc_html__( 'JS Templates', 'osteo-syntax-highlighter' ),
                    'language-julia'                    => esc_html__( 'Julia', 'osteo-syntax-highlighter' ),
                    'language-keepalived'               => esc_html__( 'Keepalived Configure', 'osteo-syntax-highlighter' ),
                    'language-keyman'                   => esc_html__( 'Keyman', 'osteo-syntax-highlighter' ),
                    'language-kotlin'                   => esc_html__( 'Kotlin', 'osteo-syntax-highlighter' ),
                    'language-kumir'                    => esc_html__( 'KuMir (КуМир)', 'osteo-syntax-highlighter' ),
                    'language-kusto'                    => esc_html__( 'Kusto', 'osteo-syntax-highlighter' ),
                    'language-latex'                    => esc_html__( 'LaTeX', 'osteo-syntax-highlighter' ),
                    'language-latte'                    => esc_html__( 'Latte', 'osteo-syntax-highlighter' ),
                    'language-less'                     => esc_html__( 'Less', 'osteo-syntax-highlighter' ),
                    'language-lilypond'                 => esc_html__( 'LilyPond', 'osteo-syntax-highlighter' ),
                    'language-liquid'                   => esc_html__( 'Liquid', 'osteo-syntax-highlighter' ),
                    'language-lisp'                     => esc_html__( 'Lisp', 'osteo-syntax-highlighter' ),
                    'language-livescript'               => esc_html__( 'LiveScript', 'osteo-syntax-highlighter' ),
                    'language-llvm'                     => esc_html__( 'LLVM', 'osteo-syntax-highlighter' ),
                    'language-log'                      => esc_html__( 'Log file', 'osteo-syntax-highlighter' ),
                    'language-lolcode'                  => esc_html__( 'LOLCODE', 'osteo-syntax-highlighter' ),
                    'language-lua'                      => esc_html__( 'Lua', 'osteo-syntax-highlighter' ),
                    'language-magma'                    => esc_html__( 'Magma (CAS)', 'osteo-syntax-highlighter' ),
                    'language-makefile'                 => esc_html__( 'Makefile', 'osteo-syntax-highlighter' ),
                    'language-markdown'                 => esc_html__( 'Markdown', 'osteo-syntax-highlighter' ),
                    'language-markup-templating'        => esc_html__( 'Markup templating', 'osteo-syntax-highlighter' ),
                    'language-matlab'                   => esc_html__( 'MATLAB', 'osteo-syntax-highlighter' ),
                    'language-maxscript'                => esc_html__( 'MAXScript', 'osteo-syntax-highlighter' ),
                    'language-mel'                      => esc_html__( 'MEL', 'osteo-syntax-highlighter' ),
                    'language-mermaid'                  => esc_html__( 'Mermaid', 'osteo-syntax-highlighter' ),
                    'language-mizar'                    => esc_html__( 'Mizar', 'osteo-syntax-highlighter' ),
                    'language-mongodb'                  => esc_html__( 'MongoDB', 'osteo-syntax-highlighter' ),
                    'language-monkey'                   => esc_html__( 'Monkey', 'osteo-syntax-highlighter' ),
                    'language-moonscript'               => esc_html__( 'MoonScript', 'osteo-syntax-highlighter' ),
                    'language-n1ql'                     => esc_html__( 'N1QL', 'osteo-syntax-highlighter' ),
                    'language-n4js'                     => esc_html__( 'N4JS', 'osteo-syntax-highlighter' ),
                    'language-nand2tetris-hdl'          => esc_html__( 'Nand To Tetris HDL', 'osteo-syntax-highlighter' ),
                    'language-naniscript'               => esc_html__( 'Naninovel Script', 'osteo-syntax-highlighter' ),
                    'language-nasm'                     => esc_html__( 'NASM', 'osteo-syntax-highlighter' ),
                    'language-neon'                     => esc_html__( 'NEON', 'osteo-syntax-highlighter' ),
                    'language-nevod'                    => esc_html__( 'Nevod', 'osteo-syntax-highlighter' ),
                    'language-nginx'                    => esc_html__( 'nginx', 'osteo-syntax-highlighter' ),
                    'language-nim'                      => esc_html__( 'Nim', 'osteo-syntax-highlighter' ),
                    'language-nix'                      => esc_html__( 'Nix', 'osteo-syntax-highlighter' ),
                    'language-nsis'                     => esc_html__( 'NSIS', 'osteo-syntax-highlighter' ),
                    'language-objectivec'               => esc_html__( 'Objective-C', 'osteo-syntax-highlighter' ),
                    'language-ocaml'                    => esc_html__( 'OCaml', 'osteo-syntax-highlighter' ),
                    'language-opencl'                   => esc_html__( 'OpenCL', 'osteo-syntax-highlighter' ),
                    'language-openqasm'                 => esc_html__( 'OpenQasm', 'osteo-syntax-highlighter' ),
                    'language-oz'                       => esc_html__( 'Oz', 'osteo-syntax-highlighter' ),
                    'language-parigp'                   => esc_html__( 'PARI/GP', 'osteo-syntax-highlighter' ),
                    'language-parser'                   => esc_html__( 'Parser', 'osteo-syntax-highlighter' ),
                    'language-pascal'                   => esc_html__( 'Pascal', 'osteo-syntax-highlighter' ),
                    'language-pascaligo'                => esc_html__( 'Pascaligo', 'osteo-syntax-highlighter' ),
                    'language-psl'                      => esc_html__( 'PATROL Scripting Language', 'osteo-syntax-highlighter' ),
                    'language-pcaxis'                   => esc_html__( 'PC-Axis', 'osteo-syntax-highlighter' ),
                    'language-peoplecode'               => esc_html__( 'PeopleCode', 'osteo-syntax-highlighter' ),
                    'language-perl'                     => esc_html__( 'Perl', 'osteo-syntax-highlighter' ),
                    'language-php'                      => esc_html__( 'PHP', 'osteo-syntax-highlighter' ),
                    'language-phpdoc'                   => esc_html__( 'PHPDoc', 'osteo-syntax-highlighter' ),
                    'language-php-extras'               => esc_html__( 'PHP Extras', 'osteo-syntax-highlighter' ),
                    'language-plsql'                    => esc_html__( 'PL/SQL', 'osteo-syntax-highlighter' ),
                    'language-powerquery'               => esc_html__( 'PowerQuery', 'osteo-syntax-highlighter' ),
                    'language-powershell'               => esc_html__( 'PowerShell', 'osteo-syntax-highlighter' ),
                    'language-processing'               => esc_html__( 'Processing', 'osteo-syntax-highlighter' ),
                    'language-prolog'                   => esc_html__( 'Prolog', 'osteo-syntax-highlighter' ),
                    'language-promql'                   => esc_html__( 'PromQL', 'osteo-syntax-highlighter' ),
                    'language-properties'               => esc_html__( 'Properties', 'osteo-syntax-highlighter' ),
                    'language-protobuf'                 => esc_html__( 'Protocol Buffers', 'osteo-syntax-highlighter' ),
                    'language-pug'                      => esc_html__( 'Pug', 'osteo-syntax-highlighter' ),
                    'language-puppet'                   => esc_html__( 'Puppet', 'osteo-syntax-highlighter' ),
                    'language-pure'                     => esc_html__( 'Pure', 'osteo-syntax-highlighter' ),
                    'language-purebasic'                => esc_html__( 'PureBasic', 'osteo-syntax-highlighter' ),
                    'language-purescript'               => esc_html__( 'PureScript', 'osteo-syntax-highlighter' ),
                    'language-python'                   => esc_html__( 'Python', 'osteo-syntax-highlighter' ),
                    'language-qsharp'                   => esc_html__( 'Q#', 'osteo-syntax-highlighter' ),
                    'language-q'                        => esc_html__( 'Q (kdb+ database)', 'osteo-syntax-highlighter' ),
                    'language-qml'                      => esc_html__( 'QML', 'osteo-syntax-highlighter' ),
                    'language-qore'                     => esc_html__( 'Qore', 'osteo-syntax-highlighter' ),
                    'language-r'                        => esc_html__( 'R', 'osteo-syntax-highlighter' ),
                    'language-racket'                   => esc_html__( 'Racket', 'osteo-syntax-highlighter' ),
                    'language-cshtml'                   => esc_html__( 'Razor C#', 'osteo-syntax-highlighter' ),
                    'language-jsx'                      => esc_html__( 'React JSX', 'osteo-syntax-highlighter' ),
                    'language-tsx'                      => esc_html__( 'React TSX', 'osteo-syntax-highlighter' ),
                    'language-reason'                   => esc_html__( 'Reason', 'osteo-syntax-highlighter' ),
                    'language-regex'                    => esc_html__( 'Regex', 'osteo-syntax-highlighter' ),
                    'language-rego'                     => esc_html__( 'Rego', 'osteo-syntax-highlighter' ),
                    'language-renpy'                    => esc_html__( 'Renpy', 'osteo-syntax-highlighter' ),
                    'language-rest'                     => esc_html__( 'reST (reStructuredText)', 'osteo-syntax-highlighter' ),
                    'language-rip'                      => esc_html__( 'Rip', 'osteo-syntax-highlighter' ),
                    'language-roboconf'                 => esc_html__( 'Roboconf', 'osteo-syntax-highlighter' ),
                    'language-robotframework'           => esc_html__( 'Robot Framework', 'osteo-syntax-highlighter' ),
                    'language-ruby'                     => esc_html__( 'Ruby', 'osteo-syntax-highlighter' ),
                    'language-rust'                     => esc_html__( 'Rust', 'osteo-syntax-highlighter' ),
                    'language-sas'                      => esc_html__( 'SAS', 'osteo-syntax-highlighter' ),
                    'language-sass'                     => esc_html__( 'Sass', 'osteo-syntax-highlighter' ),
                    'language-scss'                     => esc_html__( 'Scss', 'osteo-syntax-highlighter' ),
                    'language-scala'                    => esc_html__( 'Scala', 'osteo-syntax-highlighter' ),
                    'language-scheme'                   => esc_html__( 'Scheme', 'osteo-syntax-highlighter' ),
                    'language-shell-session'            => esc_html__( 'Shell session', 'osteo-syntax-highlighter' ),
                    'language-smali'                    => esc_html__( 'Smali', 'osteo-syntax-highlighter' ),
                    'language-smalltalk'                => esc_html__( 'Smalltalk', 'osteo-syntax-highlighter' ),
                    'language-smarty'                   => esc_html__( 'Smarty', 'osteo-syntax-highlighter' ),
                    'language-sml'                      => esc_html__( 'SML', 'osteo-syntax-highlighter' ),
                    'language-solidity'                 => esc_html__( 'Solidity (Ethereum)', 'osteo-syntax-highlighter' ),
                    'language-solution-file'            => esc_html__( 'Solution file', 'osteo-syntax-highlighter' ),
                    'language-sql'                      => esc_html__( 'Soy (Closure Template)', 'osteo-syntax-highlighter' ),
                    'language-sparql'                   => esc_html__( 'SPARQL', 'osteo-syntax-highlighter' ),
                    'language-splunk-spl'               => esc_html__( 'Splunk SPL', 'osteo-syntax-highlighter' ),
                    'language-sqf'                      => esc_html__( 'SQF: Status Quo Function (Arma 3)', 'osteo-syntax-highlighter' ),
                    'language-sql'                      => esc_html__( 'SQL', 'osteo-syntax-highlighter' ),
                    'language-squirrel'                 => esc_html__( 'Squirrel', 'osteo-syntax-highlighter' ),
                    'language-stan'                     => esc_html__( 'Stan', 'osteo-syntax-highlighter' ),
                    'language-iecst'                    => esc_html__( 'Structured Text (IEC 61131-3)', 'osteo-syntax-highlighter' ),
                    'language-stylus'                   => esc_html__( 'Stylus', 'osteo-syntax-highlighter' ),
                    'language-swift'                    => esc_html__( 'Swift', 'osteo-syntax-highlighter' ),
                    'language-systemd'                  => esc_html__( 'Systemd configuration file', 'osteo-syntax-highlighter' ),
                    'language-t4-templating'            => esc_html__( 'T4 templating', 'osteo-syntax-highlighter' ),
                    'language-t4-cs'                    => esc_html__( 'T4 Text Templates (C#)', 'osteo-syntax-highlighter' ),
                    'language-t4-vb'                    => esc_html__( 'T4 Text Templates (VB)', 'osteo-syntax-highlighter' ),
                    'language-tap'                      => esc_html__( 'TAP', 'osteo-syntax-highlighter' ),
                    'language-tcl'                      => esc_html__( 'Tcl', 'osteo-syntax-highlighter' ),
                    'language-tt2'                      => esc_html__( 'Template Toolkit 2', 'osteo-syntax-highlighter' ),
                    'language-textile'                  => esc_html__( 'Textile', 'osteo-syntax-highlighter' ),
                    'language-toml'                     => esc_html__( 'TOML', 'osteo-syntax-highlighter' ),
                    'language-tremor'                   => esc_html__( 'Tremor', 'osteo-syntax-highlighter' ),
                    'language-tremor'                   => esc_html__( 'Turtle', 'osteo-syntax-highlighter' ),
                    'language-twig'                     => esc_html__( 'Twig', 'osteo-syntax-highlighter' ),
                    'language-typescript'               => esc_html__( 'TypeScript', 'osteo-syntax-highlighter' ),
                    'language-typoscript'               => esc_html__( 'TypoScript', 'osteo-syntax-highlighter' ),
                    'language-unrealscript'             => esc_html__( 'UnrealScript', 'osteo-syntax-highlighter' ),
                    'language-uri'                      => esc_html__( 'URI', 'osteo-syntax-highlighter' ),
                    'language-v'                        => esc_html__( 'V', 'osteo-syntax-highlighter' ),
                    'language-vala'                     => esc_html__( 'Vala', 'osteo-syntax-highlighter' ),
                    'language-vbnet'                    => esc_html__( 'VB.Net', 'osteo-syntax-highlighter' ),
                    'language-velocity'                 => esc_html__( 'Velocity', 'osteo-syntax-highlighter' ),
                    'language-verilog'                  => esc_html__( 'Verilog', 'osteo-syntax-highlighter' ),
                    'language-vhdl'                     => esc_html__( 'VHDL', 'osteo-syntax-highlighter' ),
                    'language-vim'                      => esc_html__( 'Vim', 'osteo-syntax-highlighter' ),
                    'language-visual-basic'             => esc_html__( 'Visual Basic', 'osteo-syntax-highlighter' ),
                    'language-warpscript'               => esc_html__( 'WarpScript', 'osteo-syntax-highlighter' ),
                    'language-wasm'                     => esc_html__( 'WebAssembly', 'osteo-syntax-highlighter' ),
                    'language-web-idl'                  => esc_html__( 'Web IDL', 'osteo-syntax-highlighter' ),
                    'language-wiki'                     => esc_html__( 'Wiki markup', 'osteo-syntax-highlighter' ),
                    'language-wolfram'                  => esc_html__( 'Wolfram language', 'osteo-syntax-highlighter' ),
                    'language-wren'                     => esc_html__( 'Wren', 'osteo-syntax-highlighter' ),
                    'language-xeora'                    => esc_html__( 'Xeora', 'osteo-syntax-highlighter' ),
                    'language-xml-doc'                  => esc_html__( 'XML doc (.net)', 'osteo-syntax-highlighter' ),
                    'language-xojo'                     => esc_html__( 'Xojo (REALbasic)', 'osteo-syntax-highlighter' ),
                    'language-xquery'                   => esc_html__( 'XQuery', 'osteo-syntax-highlighter' ),
                    'language-yaml'                     => esc_html__( 'YAML', 'osteo-syntax-highlighter' ),
                    'language-yang'                     => esc_html__( 'YANG', 'osteo-syntax-highlighter' ),
                    'language-zig'                      => esc_html__( 'Zig', 'osteo-syntax-highlighter' ),
                    'language-treeview'                 => esc_html__( 'Treeview', 'osteo-syntax-highlighter' ),
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_theme',
            [
                'label'   => esc_html__( 'Theme', 'osteo-syntax-highlighter' ),
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'default' => 'osteo-darcula',
                'options' => [
                    'osteo-atom-one-dark'                    => esc_html__( 'Atom One Dark', 'osteo-syntax-highlighter' ),
                    'osteo-atom-one-light'                   => esc_html__( 'Atom One Light', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-dark-bordered'                => esc_html__( 'Ayu Dark Bordered', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-dark'                         => esc_html__( 'Ayu Dark', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-light-bordered'               => esc_html__( 'Ayu Light Bordered', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-light'                        => esc_html__( 'Ayu Light', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-mirage-bordered'              => esc_html__( 'Ayu Mirage Bordered', 'osteo-syntax-highlighter' ),
                    'osteo-ayu-mirage'                       => esc_html__( 'Ayu Mirage', 'osteo-syntax-highlighter' ),
                    'osteo-bluloco-light'                    => esc_html__( 'Bluloco Light', 'osteo-syntax-highlighter' ),
                    'osteo-bracket-lights-pro'               => esc_html__( 'Bracket Lights Pro', 'osteo-syntax-highlighter' ),
                    'osteo-coldark-cold'                     => esc_html__( 'Coldark Cold', 'osteo-syntax-highlighter' ),
                    'osteo-coldark-dark'                     => esc_html__( 'Coldark Dark', 'osteo-syntax-highlighter' ),
                    'osteo-darcula'                          => esc_html__( 'Darcula', 'osteo-syntax-highlighter' ),
                    'osteo-doutone-dark-earth'               => esc_html__( 'Doutone Dark Earth', 'osteo-syntax-highlighter' ),
                    'osteo-doutone-dark-forest'              => esc_html__( 'Doutone Dark Forest', 'osteo-syntax-highlighter' ),
                    'osteo-doutone-dark-sea'                 => esc_html__( 'Doutone Dark Sea', 'osteo-syntax-highlighter' ),
                    'osteo-doutone-dark-sky'                 => esc_html__( 'Doutone Dark Sky', 'osteo-syntax-highlighter' ),
                    'osteo-doutone-dark-space'               => esc_html__( 'Doutone Dark Space', 'osteo-syntax-highlighter' ),
                    'osteo-dracula'                          => esc_html__( 'Dracula', 'osteo-syntax-highlighter' ),
                    'osteo-github-dark-colorblind'           => esc_html__( 'Github Dark Colorblind', 'osteo-syntax-highlighter' ),
                    'osteo-github-dark-default'              => esc_html__( 'Github Dark Default', 'osteo-syntax-highlighter' ),
                    'osteo-github-dark-dimmed'               => esc_html__( 'Github Dark Dimmed', 'osteo-syntax-highlighter' ),
                    'osteo-github-dark-high-contrast'        => esc_html__( 'Github Dark High Contrast', 'osteo-syntax-highlighter' ),
                    'osteo-github-dark'                      => esc_html__( 'Github Dark', 'osteo-syntax-highlighter' ),
                    'osteo-github-light-colorblind'          => esc_html__( 'Github Light Colorblind', 'osteo-syntax-highlighter' ),
                    'osteo-github-light-default'             => esc_html__( 'Github Light Default', 'osteo-syntax-highlighter' ),
                    'osteo-github-light'                     => esc_html__( 'Github Light', 'osteo-syntax-highlighter' ),
                    'osteo-lws-blue-velvet'                  => esc_html__( 'LWS Blue Velvet', 'osteo-syntax-highlighter' ),
                    'osteo-lws-dracula-version'              => esc_html__( 'LWS Dracula Version', 'osteo-syntax-highlighter' ),
                    'osteo-lws-peace-of-eye-dracula-version' => esc_html__( 'LWS Peace of Eye Dracula Version', 'osteo-syntax-highlighter' ),
                    'osteo-lws-peace-of-eye'                 => esc_html__( 'LWS Peace of Eye', 'osteo-syntax-highlighter' ),
                    'osteo-lws-shades-of-gray'               => esc_html__( 'LWS Shades of Gray', 'osteo-syntax-highlighter' ),
                    'osteo-lws-simple-as-light'              => esc_html__( 'Lws Simple as Light', 'osteo-syntax-highlighter' ),
                    'osteo-lws-theme'                        => esc_html__( 'LWS Theme', 'osteo-syntax-highlighter' ),
                    'osteo-lws-vintage'                      => esc_html__( 'LWS Vintage', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-pro-machine'              => esc_html__( 'Monokai Pro Machine', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-pro-octagon'              => esc_html__( 'Monokai Pro Octagon', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-pro-restretto'            => esc_html__( 'Monokai Pro Restretto', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-pro-spectrum'             => esc_html__( 'Monokai Pro Spectrum', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-pro'                      => esc_html__( 'Monokai Pro', 'osteo-syntax-highlighter' ),
                    'osteo-monokoi-classic'                  => esc_html__( 'Monokai Classic', 'osteo-syntax-highlighter' ),
                    'osteo-night-owl-light'                  => esc_html__( 'Night Owl Light', 'osteo-syntax-highlighter' ),
                    'osteo-night-owl'                        => esc_html__( 'Night Owl', 'osteo-syntax-highlighter' ),
                    'osteo-nord'                             => esc_html__( 'Nord', 'osteo-syntax-highlighter' ),
                    'osteo-nd-dark'                          => esc_html__( 'Nu Disco Dark', 'osteo-syntax-highlighter' ),
                    'osteo-nd-light'                         => esc_html__( 'Nu Disco Light', 'osteo-syntax-highlighter' ),
                    'osteo-one-dark-pro-darker'              => esc_html__( 'One Dark Pro Darker', 'osteo-syntax-highlighter' ),
                    'osteo-one-dark-pro-flat'                => esc_html__( 'One Dark Pro Flat', 'osteo-syntax-highlighter' ),
                    'osteo-one-dark-pro'                     => esc_html__( 'One Dark Pro', 'osteo-syntax-highlighter' ),
                    'osteo-quiet-light'                      => esc_html__( 'Quiet Light', 'osteo-syntax-highlighter' ),
                    'osteo-shades-of-purple'                 => esc_html__( 'Shades of Purple', 'osteo-syntax-highlighter' ),
                    'osteo-sm-dark'                          => esc_html__( 'Sublime Material Dark', 'osteo-syntax-highlighter' ),
                    'osteo-sm-light'                         => esc_html__( 'Sublime Material Light', 'osteo-syntax-highlighter' ),
                    'osteo-synthwave-84'                     => esc_html__( 'Synthwave 84', 'osteo-syntax-highlighter' ),
                    'osteo-tokyo-night-storm'                => esc_html__( 'Tokyo Night Storm', 'osteo-syntax-highlighter' ),
                    'osteo-tokyo-night'                      => esc_html__( 'Tokyo Night', 'osteo-syntax-highlighter' ),
                    'osteo-abyss-dark'                       => esc_html__( 'Abyss Dark', 'osteo-syntax-highlighter' ),
                    'osteo-dark-plus'                        => esc_html__( 'Dark Plus', 'osteo-syntax-highlighter' ),
                    'osteo-dark'                             => esc_html__( 'Dark', 'osteo-syntax-highlighter' ),
                    'osteo-high-contrast'                    => esc_html__( 'High Contrast', 'osteo-syntax-highlighter' ),
                    'osteo-kimbie-dark'                      => esc_html__( 'Kimbie Dark', 'osteo-syntax-highlighter' ),
                    'osteo-light-plus'                       => esc_html__( 'Light Plus', 'osteo-syntax-highlighter' ),
                    'osteo-light'                            => esc_html__( 'Light', 'osteo-syntax-highlighter' ),
                    'osteo-monokai-dimmed'                   => esc_html__( 'Monokai Dimmed', 'osteo-syntax-highlighter' ),
                    'osteo-monokai'                          => esc_html__( 'Monokai', 'osteo-syntax-highlighter' ),
                    'osteo-red'                              => esc_html__( 'Red', 'osteo-syntax-highlighter' ),
                    'osteo-solarized-dark'                   => esc_html__( 'Solarized Dark', 'osteo-syntax-highlighter' ),
                    'osteo-solarized-light'                  => esc_html__( 'Solarized Light', 'osteo-syntax-highlighter' ),
                    'osteo-tomorrow-night-blue'              => esc_html__( 'Tomorrow Night Blue', 'osteo-syntax-highlighter' ),
                    'osteo-wic-dark-black'                   => esc_html__( 'WIC Dark Black', 'osteo-syntax-highlighter' ),
                    'osteo-wic-dark-blue'                    => esc_html__( 'WIC Dark Blue', 'osteo-syntax-highlighter' ),
                    'osteo-wic-light'                        => esc_html__( 'WIC Light', 'osteo-syntax-highlighter' ),
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_code_snippet',
            [
                'label'   => esc_html__( 'Code Snippet', 'osteo-syntax-highlighter' ),
                'type'    => \Elementor\Controls_Manager::TEXTAREA,
                'rows'    => 10,
                'default' => '<?php echo $osteo_syntax_highlighter_code_snippet; ?>',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_copy',
            [
                'label'   => esc_html__( 'Copy', 'osteo-syntax-highlighter' ),
                'type'    => \Elementor\Controls_Manager::TEXTAREA,
                'rows'    => 5,
                'default' => 'Copy',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_copy_success',
            [
                'label'   => esc_html__( 'Copy Success', 'osteo-syntax-highlighter' ),
                'type'    => \Elementor\Controls_Manager::TEXTAREA,
                'rows'    => 5,
                'default' => 'Copy Done!',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_syntax_highlighter_feature_section',
            [
                'label' => esc_html__( 'Features', 'osteo-syntax-highlighter' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_line_number',
            [
                'label'        => esc_html__( 'Line Number', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'line-numbers',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_line_highlight',
            [
                'label'       => esc_html__( 'Line Number', 'osteo-syntax-highlighter' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'default'     => '2-11',
                'description' => esc_html__( 'You can write line numbers using two ways. Way-1: 2-11, 20-29 Way-2: 2,3,4,5', 'osteo-syntax-highlighter' ),
                'condition'   => [
                    'osteo_syntax_highlighter_line_number' => ['line-numbers'],
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_normalize_whitespace',
            [
                'label'        => esc_html__( 'Normalize Whitespace', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'no-whitespace-normalization',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_match_braces',
            [
                'label'        => esc_html__( 'Match Braces', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'match-braces',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_rainbow_braces',
            [
                'label'        => esc_html__( 'Rainbow Braces', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'rainbow-braces',
                'default'      => 'no',
                'condition'    => [
                    'osteo_syntax_highlighter_match_braces' => ['match-braces'],
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_inline_color',
            [
                'label'        => esc_html__( 'Inline Color', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'inline-color',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_previewers',
            [
                'label'        => esc_html__( 'Previewers', 'osteo-syntax-highlighter' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo-syntax-highlighter' ),
                'label_off'    => esc_html__( 'Hide', 'osteo-syntax-highlighter' ),
                'return_value' => 'angle color gradient easing time',
                'default'      => 'no',
                'description'  => esc_html__( 'Previewers only works for (angle, color, gradient, easing, time).', 'osteo-syntax-highlighter' ),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_syntax_highlighter_style_section',
            [
                'label' => esc_html__( 'Content', 'osteo-syntax-highlighter' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_inline_code_color',
            [
                'label'     => esc_html__( 'Inline Code Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} :not(pre)>code[class*="language-"]' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_inline_code_bg',
            [
                'label'     => esc_html__( 'Inline Code Background', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} :not(pre)>code[class*="language-"]' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_base_color',
            [
                'label'     => esc_html__( 'Base Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} pre[class*="language-"]'  => 'color: {{VALUE}}',
                    '{{WRAPPER}} code[class*="language-"]' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_code_block_bg',
            [
                'label'     => esc_html__( 'Code Blocks Background', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} pre[class*="language-"]' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_comment_color',
            [
                'label'     => esc_html__( 'Comment Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.comment' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.prolog'  => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.doctype' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.cdata'   => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_punctuation_color',
            [
                'label'     => esc_html__( 'Punctuation Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.punctuation' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_property_color',
            [
                'label'     => esc_html__( 'Property Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.property' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.tag'      => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.boolean'  => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.number'   => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.constant' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.symbol'   => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.deleted'  => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_selector_color',
            [
                'label'     => esc_html__( 'Selector Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.selector'  => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.attr-name' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.string'    => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.char'      => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.builtin'   => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.inserted'  => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_operator_color',
            [
                'label'     => esc_html__( 'Operator Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.operator'             => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.entity'               => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.url'                  => 'color: {{VALUE}}',
                    '{{WRAPPER}} .language-css .token.string' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .style .token.string'        => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_operator_background',
            [
                'label'     => esc_html__( 'Operator Background', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.operator'             => 'background: {{VALUE}}',
                    '{{WRAPPER}} .token.entity'               => 'background: {{VALUE}}',
                    '{{WRAPPER}} .token.url'                  => 'background: {{VALUE}}',
                    '{{WRAPPER}} .language-css .token.string' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .style .token.string'        => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_keyword_color',
            [
                'label'     => esc_html__( 'Keyword Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.atrule'     => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.attr-value' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.keyword'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_function_color',
            [
                'label'     => esc_html__( 'Function Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.function' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_variable_color',
            [
                'label'     => esc_html__( 'Variable Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .token.regex'     => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.important' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .token.variable'  => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_line_highlight_background',
            [
                'label'     => esc_html__( 'Line Highlight Background', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .line-highlight' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_line_highlight_accent',
            [
                'label'     => esc_html__( 'Line Highlight Accent', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .line-highlight' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_font_size',
            [
                'label'       => esc_html__( 'Font Size', 'osteo-syntax-highlighter' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'description' => 'If line number is not showing properly, save font size and reload. Now working!',
                'range'       => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 90,
                        'step' => 1,
                    ],
                ],
                'default'     => [
                    'unit' => 'px',
                    'size' => 16,
                ],
                'selectors'   => [
                    '{{WRAPPER}} .osteo-syntax-highlighter pre[class*="language-"]'  => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .osteo-syntax-highlighter code[class*="language-"]' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_syntax_highlighter_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'osteo-syntax-highlighter' ),
                'selector' => '{{WRAPPER}} .osteo-syntax-highlighter',
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_toolbar_color',
            [
                'label'     => esc_html__( 'Toolbar Color', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} div.code-toolbar>.toolbar>.toolbar-item>a, div.code-toolbar>.toolbar>.toolbar-item>a:hover, div.code-toolbar>.toolbar>.toolbar-item>a:focus, div.code-toolbar>.toolbar>.toolbar-item>button, div.code-toolbar>.toolbar>.toolbar-item>button:hover, div.code-toolbar>.toolbar>.toolbar-item>button:focus, div.code-toolbar>.toolbar>.toolbar-item>span, div.code-toolbar>.toolbar>.toolbar-item>span:hover, div.code-toolbar>.toolbar>.toolbar-item>span:focus' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_toolbar_background',
            [
                'label'     => esc_html__( 'Toolbar Background', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} div.code-toolbar>.toolbar>.toolbar-item>a, div.code-toolbar>.toolbar>.toolbar-item>a:hover, div.code-toolbar>.toolbar>.toolbar-item>a:focus, div.code-toolbar>.toolbar>.toolbar-item>button, div.code-toolbar>.toolbar>.toolbar-item>button:hover, div.code-toolbar>.toolbar>.toolbar-item>button:focus, div.code-toolbar>.toolbar>.toolbar-item>span, div.code-toolbar>.toolbar>.toolbar-item>span:hover, div.code-toolbar>.toolbar>.toolbar-item>span:focus' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_syntax_highlighter_toolbar_border_radius',
            [
                'label'     => esc_html__( 'Toolbar Border Radius', 'osteo-syntax-highlighter' ),
                'type'      => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} div.code-toolbar>.toolbar>.toolbar-item>a, div.code-toolbar>.toolbar>.toolbar-item>a:hover, div.code-toolbar>.toolbar>.toolbar-item>a:focus, div.code-toolbar>.toolbar>.toolbar-item>button, div.code-toolbar>.toolbar>.toolbar-item>button:hover, div.code-toolbar>.toolbar>.toolbar-item>button:focus, div.code-toolbar>.toolbar>.toolbar-item>span, div.code-toolbar>.toolbar>.toolbar-item>span:hover, div.code-toolbar>.toolbar>.toolbar-item>span:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        ?>

        <div class="osteo-syntax-highlighter <?php echo esc_attr( $settings['osteo_syntax_highlighter_theme'] ); ?> show-language diff-highlight <?php echo esc_attr( $settings['osteo_syntax_highlighter_normalize_whitespace'] ); ?> <?php echo esc_attr( $settings['osteo_syntax_highlighter_match_braces'] ); ?> <?php echo esc_attr( $settings['osteo_syntax_highlighter_rainbow_braces'] ); ?> <?php echo esc_attr( $settings['osteo_syntax_highlighter_inline_color'] ); ?>">
          <pre class="<?php echo esc_attr( $settings['osteo_syntax_highlighter_line_number'] ); ?>" data-line="<?php echo esc_attr( $settings['osteo_syntax_highlighter_line_highlight'] ); ?>" data-previewers="<?php echo esc_attr( $settings['osteo_syntax_highlighter_previewers'] ); ?>">
            <code class="<?php echo esc_attr( $settings['osteo_syntax_highlighter_language'] ); ?>" data-prismjs-copy="<?php echo esc_html( $settings['osteo_syntax_highlighter_copy'] ); ?>" data-prismjs-copy-success="<?php echo esc_html( $settings['osteo_syntax_highlighter_copy_success'] ); ?>">
              <?php echo esc_html( $settings['osteo_syntax_highlighter_code_snippet'] ); ?>
            </code>
          </pre>
        </div>

		<?php
}
}